Thread (19 messages) flat view 19 messages, 2 authors, 2021-09-22

Re: [PATCH 03/16] ASoC: fsl-audmix: Update to modern clocking terminology

From: Fabio Estevam <festevam@gmail.com>
Date: 2021-09-21 21:31:12
Also in: alsa-devel, linuxppc-dev

On Tue, Sep 21, 2021 at 6:11 PM Mark Brown [off-list ref] wrote:
quoted hunk ↗ jump to hunk
As part of moving to remove the old style defines for the bus clocks update
the fsl-audmix driver to use more modern terminology for clocking.

Signed-off-by: Mark Brown <broonie@kernel.org>
---
 sound/soc/fsl/fsl_audmix.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)
diff --git a/sound/soc/fsl/fsl_audmix.c b/sound/soc/fsl/fsl_audmix.c
index f931288e256c..db2dde597edc 100644
--- a/sound/soc/fsl/fsl_audmix.c
+++ b/sound/soc/fsl/fsl_audmix.c
@@ -257,10 +257,10 @@ static int fsl_audmix_dai_set_fmt(struct snd_soc_dai *dai, unsigned int fmt)
                return -EINVAL;
        }

-       /* For playback the AUDMIX is slave, and for record is master */
-       switch (fmt & SND_SOC_DAIFMT_MASTER_MASK) {
-       case SND_SOC_DAIFMT_CBM_CFM:
-       case SND_SOC_DAIFMT_CBS_CFS:
+       /* For playback the AUDMIX is provider, and for record is consumer */
+       switch (fmt & SND_SOC_DAIFMT_CLOCK_PROVIDER_MASK) {
I think the comment should be the other way around:

       /* For playback the AUDMIX is consumer, and for record is provider */

Other than that, the series looks good.

_______________________________________________
linux-arm-kernel mailing list
linux-arm-kernel@lists.infradead.org
http://lists.infradead.org/mailman/listinfo/linux-arm-kernel
Keyboard shortcuts
hback out one level
jnext message in thread
kprevious message in thread
ldrill in
Escclose help / fold thread tree
?toggle this help